summaryrefslogtreecommitdiffstats
path: root/kpilot/kpilot/listItems.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/kpilot/listItems.h')
-rw-r--r--kpilot/kpilot/listItems.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kpilot/kpilot/listItems.h b/kpilot/kpilot/listItems.h
index 914d4b00..4987219f 100644
--- a/kpilot/kpilot/listItems.h
+++ b/kpilot/kpilot/listItems.h
@@ -3,7 +3,7 @@
** Copyright (C) 1998-2001 by Dan Pilone
** Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
**
** This file defines a subclasse of QListBoxText that carries
** additional information useful for Pilot records. In particular it
** carries an int (for the pilot's uid?) and a void * (for pilotrecord?)
*/
@@ -32,13 +32,13 @@
#ifndef _KPILOT_LISTITEMS_H
#define _KPILOT_LISTITEMS_H
-#include <qlistview.h>
+#include <tqlistview.h>
#include <pi-dlp.h>
class PilotListItem : public QListBoxText
{
public:
- PilotListItem(const QString &text, recordid_t pilotid=0, void *r=0);
+ PilotListItem(const TQString &text, recordid_t pilotid=0, void *r=0);
virtual ~PilotListItem();
recordid_t id() const {return fid;};
const void *rec() const {return fr;};
@@ -59,7 +59,7 @@ private:
class PilotCheckListItem : public QCheckListItem
{
public:
- PilotCheckListItem( QListView * parent, const QString & text, recordid_t pilotid=0, void *r=0);
+ PilotCheckListItem( TQListView * parent, const TQString & text, recordid_t pilotid=0, void *r=0);
virtual ~PilotCheckListItem();
recordid_t id() const {return fid;};
const void *rec() const {return fr;};
@@ -85,18 +85,18 @@ struct PilotListViewItemData
class PilotListViewItem : public QListViewItem
{
public:
- PilotListViewItem( QListView * parent,
- QString label1, QString label2 = QString::null,
- QString label3 = QString::null, QString label4 = QString::null,
+ PilotListViewItem( TQListView * parent,
+ TQString label1, TQString label2 = TQString::null,
+ TQString label3 = TQString::null, TQString label4 = TQString::null,
recordid_t pilotid=0, void *r=0);
virtual ~PilotListViewItem();
recordid_t id() const {return fid;};
const void *rec() const {return fr;};
public:
void setNumericCol(int col, bool numeric);
- int compare( QListViewItem *i, int col, bool ascending ) const;
+ int compare( TQListViewItem *i, int col, bool ascending ) const;
protected:
- QValueList<int> numericCols;
+ TQValueList<int> numericCols;
recordid_t fid;
void *fr;
// Caching to make sorting faster:
@@ -3,7 +3,7 @@
** Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
**
-** This file defines a subclasse of QListBoxText that carries
+** This file defines a subclasse of TQListBoxText that carries
** additional information useful for Pilot records. In particular it
** carries an int (for the pilot's uid?) and a void * (for pilotrecord?)